Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(384)

Unified Diff: dart/runtime/vm/longjump.cc

Issue 119673004: Version 1.1.0-dev.5.2 (Closed) Base URL: http://dart.googlecode.com/svn/trunk/
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « dart/runtime/vm/longjump.h ('k') | dart/runtime/vm/longjump_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dart/runtime/vm/longjump.cc
===================================================================
--- dart/runtime/vm/longjump.cc (revision 31530)
+++ dart/runtime/vm/longjump.cc (working copy)
@@ -15,13 +15,14 @@
namespace dart {
-jmp_buf* LongJump::Set() {
+jmp_buf* LongJumpScope::Set() {
+ ASSERT(top_ == NULL);
top_ = Isolate::Current()->top_resource();
return &environment_;
}
-bool LongJump::IsSafeToJump() {
+bool LongJumpScope::IsSafeToJump() {
// We do not want to jump past Dart frames. Note that this code
// assumes the stack grows from high to low.
Isolate* isolate = Isolate::Current();
@@ -35,8 +36,9 @@
}
-void LongJump::Jump(int value, const Error& error) {
- // A zero is the default return value from setting up a LongJump using Set.
+void LongJumpScope::Jump(int value, const Error& error) {
+ // A zero is the default return value from setting up a LongJumpScope
+ // using Set.
ASSERT(value != 0);
ASSERT(IsSafeToJump());
« no previous file with comments | « dart/runtime/vm/longjump.h ('k') | dart/runtime/vm/longjump_test.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698